@@ -93,31 +93,31 @@ def load_data(path):
         file = list(
             filter(lambda x: not re.findall(r"index", x), glob.glob(f"{directory}\*"))
         )
-        if len(file) > 1:
-            log(f"Multiple files not supported. Split up {directory}")
-        else:
+        if len(file) == 1:
             file = file[0]
+            try:
+                tdms_file = TdmsFile(file)
+                df = tdms_file.as_dataframe()
+                df = df[
+                    list(filter(lambda x: re.findall(r"Timestampe|CO2", x), df.columns))
+                ]
+                df.columns = ["CO2", "Time"]
+                df["Time"] = df["Time"].sub(df["Time"].min()).sub(40)
+                df.set_index("Time", inplace=True)
+                initial_condition = df[:-30].mean()
+                df = df.sub(initial_condition)
+                sample_dict[sample][sample_type][sample_rep] = df
+                df.to_csv(
+                    os.path.join(RAW_CSV_DATA, f"{sample}_{sample_type}_{sample_rep}.csv"),
+                    sep=",",
+                    index=True,
+                )
+            except [FileNotFoundError, OSError] as e:
+                log(f"{e}\t File: {file} \t Directory: {directory}")
+        else:
+            log(f"Have some files here I don't like {directory} // \n{file} \n-- Skipping this")
         # Load the TDMS File
-        try:
-            tdms_file = TdmsFile(file)
-            df = tdms_file.as_dataframe()
-            df = df[
-                list(filter(lambda x: re.findall(r"Timestampe|CO2", x), df.columns))
-            ]
-            df.columns = ["CO2", "Time"]
-            df["Time"] = df["Time"].sub(df["Time"].min()).sub(40)
-            df.set_index("Time", inplace=True)
-            initial_condition = df[:-30].mean()
-            df = df.sub(initial_condition)
-            sample_dict[sample][sample_type][sample_rep] = df
-            df.to_csv(
-                os.path.join(RAW_CSV_DATA, f"{sample}_{sample_type}_{sample_rep}.csv"),
-                sep=",",
-                index=True,
-            )
 
-        except [FileNotFoundError, OSError] as e:
-            log(f"{e}\t File: {file} \t Directory: {directory}")
     return sample_dict
 
 
